# question-cache [![NPM version](https://badge.fury.io/js/question-cache.svg)](http://badge.fury.io/js/question-cache)

> A tiny wrapper around inquirer that makes it easy to create and selectively reuse questions. Useful for project generators like yeoman or generate.

## Install with [npm](npmjs.org)

```bash
npm i question-cache --save
```

**Table of Contents**

<!-- toc -->

- [Usage](#usage)
- [API](#api)
- [Example](#example)
- [Other awesome projects](#other-awesome-projects)
- [Contributing](#contributing)
- [Author](#author)
- [License](#license)

_(Table of contents generated by [verb])_

<!-- tocstop -->

## Usage

```js
var questions = require('question-cache');

// you must pass your own instance of inquirer!
var inquirer = require('inquirer');
var questions = new Questions({inquirer: inquirer});
```

## API
### [Questions](index.js#L23)

Create an instance of `Questions` with the given `options`.

* `options` **{Object}**: Pass your instance of [inquirer] on the `inquirer` option.    

```js
var inquirer = require('inquirer')
var questions = new Questions({inquirer: inquirer});
```

### [.set](index.js#L45)

Store a question object by `key`.

* `key` **{String}**: Unique question id.    
* `value` **{Object}**: Question object that follows [inquirer] conventions.    

```js
questions.set('name', {
  type: 'input',
  message: 'Project name?',
  default: 'undefined'
});
```

### [.get](index.js#L63)

Get a question by `key`.

* `key` **{String}**: Unique question id.    
* `value` **{Object}**: Question object that follows [inquirer] conventions.    

```js
questions.get('name');
//=> {type: 'input', message: 'What is your name?', default: ''}
```

### [.ask](index.js#L80)

Ask a question or array of questions.

* `key` **{String}**: Unique question id.    
* `value` **{Object}**: Question object that follows [inquirer] conventions.    

```js
questions.ask(['name', 'homepage']);
//=> { name: 'foo', homepage: 'https://github/foo' }
```

## Example

```js
var Questions = require('question-cache');
var inquirer = require('inquirer');
var questions = new Questions({inquirer: inquirer});

questions.set('name', {
  type: 'input',
  message: 'What is your name?',
  default: ''
});

questions.set('repo', {
  type: 'input',
  message: 'What is the repo URL?',
  default: ''
});

questions.ask(['name', 'repo'], function (err, answers) {
  console.log(answers);
  //=> { repo: 'foo', name: 'bar' }
});
```

## Other awesome projects
 * [generate](https://github.com/generate/generate): Project generator, for node.js.
 * [yo](https://github.com/yeoman/yo): CLI tool for running Yeoman generators
 * [verb](https://github.com/assemble/verb): Verb makes it dead simple to generate markdown documentation, using simple templates, with zero configuration required. A project without documentation is like a project that doesn't exist.  

## Contributing
Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/question-cache/issues)

## Author

**Jon Schlinkert**

+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert) 

## License
Copyright (c) 2015 Jon Schlinkert  
Released under the MIT license

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on April 19, 2015._

[verb]: https://github.com/assemble/verb
[yeoman]: http://yeoman.io
[generate]: https://github.com/generate/generate
[inquirer]: https://github.com/SBoudrias/Inquirer.js